## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 4;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%if %{defined rhel}
%global debug_package %{nil}
%endif

# always bootstrap: otherwise rebuild fails
%bcond scm_boot 1

%bcond docs 1

# requires network?
%bcond test 0

# ppc64le s390x i686 give linking error with chez-scheme:
# - Exception: (while loading libc.so) /lib/libc.so: invalid ELF header
%ifarch ppc64le %{ix86}
# build with racket instead of chez-scheme
%bcond racket 1
%else
%bcond racket 0
%endif

%if %{with racket}
# /usr/lib/.build-id file for bin/idris2 conflicts with racket-minimal starter
%define _build_id_links alldebug
%endif

Name:           idris2
Version:        0.7.0
Release:        %autorelease
Summary:        Purely functional programming language with first class types

License:        BSD-3-Clause
URL:            https://www.idris-lang.org
Source0:        https://github.com/idris-lang/Idris2/archive/v%{version}/%{name}-%{version}.tar.gz

# i686 crashes: invalid memory reference.  Some debugging context lost
# ppc64le: extremely slow with Racket portable bytecode vm
# s390x: Exception: (while loading libc.so) /lib64/libc.so: invalid ELF header
ExcludeArch:    ppc64le s390x %{ix86}
BuildRequires:  gcc
BuildRequires:  gmp-devel
BuildRequires:  make
%if %{without scm_boot}
BuildRequires:  idris2
%endif
%if %{with docs}
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme
%endif
%if %{with test}
BuildRequires:  clang
%endif
%if %{with racket}
BuildRequires:  racket-minimal
BuildRequires:  racket-pkgs
Requires:       racket-minimal%{?_isa}
%else
BuildRequires:  chez-scheme >= 10
Requires:       chez-scheme%{?_isa} >= 10
%endif
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Provides:       %{name}-static = %{version}-%{release}

%description
Idris is a programming language designed to encourage Type-Driven Development.


%if %{with docs}
%package doc
Summary:        Idris2 documentation
%if %{defined fedora}
Requires:       fontawesome4-fonts
%else
Requires:       fontawesome-fonts
%endif
BuildArch:      noarch

%description doc
The package contains the idris2 manual
%endif


%package libs
Summary:        idris2 runtime support library
Obsoletes:      %{name}-lib < %{version}-%{release}

%description libs
The package provide the runtime support library for idris2.


%prep
%setup -q -n Idris2-%{version}


%build
%if %{with scm_boot}
make %{?with_racket:bootstrap-racket}%{!?with_racket:bootstrap SCHEME=scheme} PREFIX=%{_libdir}
%else
make
%endif

%if %{with docs}
make -C docs html
%endif


%install
export PATH=%{buildroot}/bin:$PATH
make install DESTDIR=%{buildroot} PREFIX=%{_libdir}

mkdir %{buildroot}%{_bindir}
%if %{without racket}
mv %{buildroot}%{_libdir}/bin/idris2_app/idris2.so %{buildroot}%{_bindir}/idris2
%else
mv %{buildroot}%{_libdir}/bin/idris2_app/idris2 %{buildroot}%{_bindir}/
%endif
rm %{buildroot}%{_libdir}/bin/idris2_app/libidris2_support.so

mv %{buildroot}%{_libdir}/%{name}-%{version}/lib/libidris2_support.so %{buildroot}%{_libdir}

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/
LD_LIBRARY_PATH="%{buildroot}%{_libdir}:" %{buildroot}%{_bindir}/idris2 --bash-completion-script %{name} | sed "s/dirnames/default/" > %{buildroot}%{_datadir}/bash-completion/completions/%{name}


%if %{with test}
%check
make test
%endif


# /usr/lib64/idris2-version/support/refc/libidris2_refc.a provides C backend runtime

%files
%doc *.md
%doc www/source/index.md
%{_bindir}/idris2
%{_libdir}/%{name}-%{version}
%{_datadir}/bash-completion/completions/%{name}
%exclude %{_libdir}/bin
%exclude %{_libdir}/%{name}-%{version}/lib


%if %{with docs}
%files doc
%doc docs/build/html
%endif


%files libs
%license LICENSE
%{_libdir}/libidris2_support.so


%changelog
## START: Generated by rpmautospec
* Fri Jul 04 2025 Jens Petersen <petersen@redhat.com> - 0.7.0-4
- obsolete idris2-lib

* Fri Jul 04 2025 Jens Petersen <petersen@redhat.com> - 0.7.0-3
- redisable s390x

* Wed Jul 02 2025 Jens Petersen <petersen@redhat.com> - 0.7.0-8
- rename boot bcond to scm_boot (#2314358)
- rename lib subpackage to libs (zbyszek, #2314358)

* Tue Jul 01 2025 Jens Petersen <petersen@redhat.com> - 0.7.0-7
- provides idris2-static

* Tue Jul 01 2025 Jens Petersen <petersen@redhat.com> - 0.7.0-6
- samples is gone with the archive tarball

* Mon Jan 20 2025 Jens Petersen <petersen@redhat.com> - 0.7.0-3
- use github archive tarball (zbyszek, #2314358)
- enable s390x
- rename docs subpackage to noarch doc (#2314358)
- move license file to lib (zbyszek, #2314358)

* Sun Jan 19 2025 Jens Petersen <petersen@redhat.com> - 0.7.0-2
- use modern bcond macro (#2314358)

* Tue Jun 25 2024 Jens Petersen <petersen@redhat.com> - 0.7.0-1
- update to 0.7.0
- require chez-scheme-10

* Sat Aug 19 2023 Jens Petersen <petersen@redhat.com> - 0.6.0-0.1
- update to 0.6.0
  https://github.com/idris-lang/Idris2/blob/v0.6.0/CHANGELOG.md
- revert to chez-scheme

* Mon Sep 20 2021 Jens Petersen <petersen@redhat.com> - 0.5.1-1
- update to 0.5.1

* Sat Sep  4 2021 Jens Petersen <petersen@redhat.com> - 0.4.0-3
- use the racket backend for codegen
- move main idris binary to bindir and libidris2_support.so to libdir
  and IDRIS2_PREFIX is now libdir (this all mimics the AUR packaging)
- drop rest of bindir files and libidris2_support.so copies
- drop idris-api package for now

* Thu Jul  8 2021 Jens Petersen <petersen@redhat.com>
- remove bootstrapping files from bin/idris2_app/
- change bash-completion from dirnames to default

* Wed Jul  7 2021 Jens Petersen <petersen@redhat.com> - 0.4.0-2
- install-with-src-libs and install-api
- add bash-completion

* Tue Jul  6 2021 Jens Petersen <petersen@redhat.com> - 0.4.0-1
- add DESTDIR patch

* Tue Jun 23 2020 Jens Petersen <petersen@redhat.com>
- initial packaging try

## END: Generated by rpmautospec
